@@ -1,5 +1,5 @@
 #include "aiwa.h"
-#include "necprotocol.h"
+#include "protocols/lircprotocol.h"
 
 AiwaDVD1::AiwaDVD1(
   QObject *guiObject,
@@ -9,18 +9,17 @@ AiwaDVD1::AiwaDVD1(
       Aiwa_Make,
       index)
 {
-  NECProtocol *np = new NECProtocol(
+  LIRCProtocol *lp = new LIRCProtocol(
     guiObject,
     index,
     500, 622,
     1629, 622,
-    99349, false,
-    LIRC_NEC);
+    99349, false);
 
-  threadableProtocol = np;
+  threadableProtocol = lp;
 
-  np->setHeaderPair(1623, 615);
-  np->setRepeatPair(8967, 4467);
+  lp->setHeaderPair(1623, 615);
+  lp->setRepeatPair(8967, 4467);
 
   addKey("KEY_POWER", Power_Key, 0x201, 10);
   addKey("KEY_SUBTITLE", Captions_Key, 0x32C, 10);
